==> saga-ltr-2.3.1-1-src.tar.bz2: osgeo4w/package.sh <==
#!/bin/bash

# git clone git://git.code.sf.net/p/saga-gis/code saga-gis-code
# https://github.com/wxWidgets/wxWidgets/releases/download/v3.1.0/wxMSW-3.1.0_vc100_ReleaseDLL.7z
# https://github.com/wxWidgets/wxWidgets/releases/download/v3.1.0/wxWidgets-3.1.0-headers.7z
# https://github.com/wxWidgets/wxWidgets/releases/download/v3.1.0/wxMSW-3.1.0_vc100_Dev.7z
# https://github.com/wxWidgets/wxWidgets/releases/download/v3.1.0/wxMSW-3.1.0_vc100_x64_Dev.7z
# https://github.com/libharu/libharu/archive/RELEASE_2_3_0.zip

D=$PWD

set -e


if ! [ -d "$OSGEO4W_REP" ]; then
	echo Repository not found
	exit
fi

#
# run batch file and source environment changes
#
fetchenv() {
	local IFS
	IFS=
	batch=$1	
	shift
	cmd /c set >$TEMP/srcenv
	cmd /c call `cygpath -w $batch` "$@" \>nul 2\>nul \& set >$TEMP/dstenv
	diff -u $TEMP/srcenv $TEMP/dstenv | sed -f $D/envdiff.sed >$TEMP/diffenv
	. $TEMP/diffenv
	PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
	rm -f $TEMP/srcenv $TEMP/dstenv $TEMP/diffenv
}

export P=saga-ltr
export V=2.3.1
export B=1

cd libharu-RELEASE_2_3_0

if ! [ -f lib-x86/libhpdf.lib ]; then
	(
		fetchenv /cygdrive/c/Program\ Files*/Microsoft\ Visual\ Studio\ 10.0/VC/vcvarsall.bat x86
		nmake -f ../Makefile.haru clean
		nmake -f ../Makefile.haru OSGEO4W_ROOT=C:\\OSGeo4W ARCH=x86 ZLIB=zlib PNGLIB=libpng13.lib
	)
fi
if ! [ -f lib-amd64/libhpdf.lib ]; then
	(
		fetchenv /cygdrive/c/Program\ Files*/Microsoft\ Visual\ Studio\ 10.0/VC/vcvarsall.bat amd64
		nmake -f ../Makefile.haru clean
		nmake -f ../Makefile.haru OSGEO4W_ROOT=C:\\OSGeo4W64 ARCH=amd64 ZLIB=zdll.lib PNGLIB=libpng16.lib
	)
fi

cd ../..

git reset --hard

cd saga-gis

find . -name "*.vcxproj" |
	PWD=$(cygpath -m "$D") \
	O4W_32=$(cygpath -m "c:/osgeo4w") \
	O4W_64=$(cygpath -m "c:/osgeo4w64") \
	xargs perl ../osgeo4w/replace.pl

# io_shapes_las.vcxproj 315A9D51-F880-4E45-A890-60FCC4AC71DA
# imagery_opencv.vcxproj AC303E9F-28C5-4F95-8E25-A5D59E8DB01D
# imagery_vigra.vcxproj 596A318C-D642-4397-BC7E-6B68BEAA95FC
perl -i -ne 'print unless /^\s+\{(D32A5075-9393-4541-9631-4DE087FAABAC|AC303E9F-28C5-4F95-8E25-A5D59E8DB01D|596A318C-D642-4397-BC7E-6B68BEAA95FC|315A9D51-F880-4E45-A890-60FCC4AC71DA)}/;' src/saga.vc10.sln

cd src
fetchenv /cygdrive/c/Program\ Files*/Microsoft\ Visual\ Studio\ 10.0/VC/vcvarsall.bat $VCARCH

"/c/Program Files (x86)/Microsoft Visual Studio 10.0/Common7/IDE/devenv" saga.vc10.sln /Build "Release|Win32" /Out ..\\..\\osgeo4w\\build-Win32.log
"/c/Program Files (x86)/Microsoft Visual Studio 10.0/Common7/IDE/devenv" saga.vc10.sln /Build "Release|x64" /Out ..\\..\\osgeo4w\\build-x64.log

cd ../../osgeo4w

for a in x86 x86_64; do
	mkdir -p $a/bin $a/etc/postinstall $a/etc/preremove $a/apps/$P

	cat <<EOF >$a/bin/${P}_gui.bat
call "%~dp0\\o4w_env.bat"
"%OSGEO4W_ROOT%\\apps\\$P\\saga_gui.exe"
EOF

	cat <<EOF >$a/etc/postinstall/$P.bat
if "%OSGEO4W_DESKTOP%"=="" set OSGEO4W_DESKTOP=%ALLUSERSPROFILE%\\Desktop

if not %OSGEO4W_DESKTOP_LINKS%==0 mkdir "%OSGEO4W_DESKTOP%"
if not %OSGEO4W_DESKTOP_LINKS%==0 nircmd shortcut "%OSGEO4W_ROOT%\\bin\\nircmd.exe" "%OSGEO4W_DESKTOP%" "SAGA GIS ($V)" "exec hide "%OSGEO4W_ROOT%\\bin\\${P}_gui.bat""" "%OSGEO4W_ROOT%\\apps\\$P\\saga_gui.exe"

if not %OSGEO4W_MENU_LINKS%==0 mkdir "%OSGEO4W_STARTMENU%"
if not %OSGEO4W_MENU_LINKS%==0 nircmd shortcut "%OSGEO4W_ROOT%\\bin\\nircmd.exe" "%OSGEO4W_STARTMENU%" "SAGA GIS ($V)" "exec hide "%OSGEO4W_ROOT%\\bin\\${P}_gui.bat""" "%OSGEO4W_ROOT%\\apps\\$P\\saga_gui.exe"
EOF

	cat <<EOF >$a/etc/preremove/$P.bat
del "%OSGEO4W_STARTMENU%\\SAGA GIS ($V).lnk"
del "%ALLUSERSPROFILE%\\Desktop\\SAGA GIS ($V).lnk"
EOF

done

(
	cd ../saga-gis/bin/saga_vc_Win32
	tar -cf - \
		modules/*.dll \
		saga.*.txt \
		saga_api.dll \
		saga_gdi.dll \
		saga_cmd.exe \
		saga_gui.exe \
		saga_prj.*
) | tar -C x86/apps/$P -xf -

(
	cd ../saga-gis/bin/saga_vc_x64
	tar -cf - \
		modules/*.dll \
		saga.*.txt \
		saga_api.dll \
		saga_gdi.dll \
		saga_cmd.exe \
		saga_gui.exe \
		saga_prj.* \
) | tar -C x86_64/apps/$P -xf -

tar -C lib/vc100_dll -cf - \
	wxbase310u_vc100.dll \
	wxbase310u_net_vc100.dll \
	wxbase310u_xml_vc100.dll \
	wxmsw310u_adv_vc100.dll \
	wxmsw310u_aui_vc100.dll \
	wxmsw310u_core_vc100.dll \
	wxmsw310u_html_vc100.dll \
	wxmsw310u_propgrid_vc100.dll \
	| tar -C x86/apps/$P -xf -

tar -C lib/vc100_x64_dll -cf - \
	wxbase310u_vc100_x64.dll \
	wxbase310u_net_vc100_x64.dll \
	wxbase310u_xml_vc100_x64.dll \
	wxmsw310u_adv_vc100_x64.dll \
	wxmsw310u_aui_vc100_x64.dll \
	wxmsw310u_core_vc100_x64.dll \
	wxmsw310u_html_vc100_x64.dll \
	wxmsw310u_propgrid_vc100_x64.dll \
	| tar -C x86_64/apps/$P -xf -

for a in x86 x86_64; do
	mkdir -p $OSGEO4W_REP/$a/release/saga/$P

	tar -C $a -cjf $OSGEO4W_REP/$a/release/saga/$P/$P-$V-$B.tar.bz2 apps bin etc
	tar -C .. -cjf $OSGEO4W_REP/$a/release/saga/$P/$P-$V-$B-src.tar.bz2 \
		osgeo4w/package.sh \
		osgeo4w/envdiff.sed \
		osgeo4w/replace.pl \
		osgeo4w/Makefile.haru

	cat <<EOF >$OSGEO4W_REP/$a/release/saga/$P/setup.hint
sdesc: "SAGA (System for Automated Geographical Analyses; long-term release)"
ldesc: "SAGA (System for Automated Geographical Analyses; long-term release)"
requires:
maintainer: JuergenFischer
category: Desktop
EOF
done

==> saga-ltr-2.3.2-1-src.tar.bz2: osgeo4w/package.sh <==
#!/bin/bash

# git clone git://git.code.sf.net/p/saga-gis/code saga-gis-code
# https://github.com/wxWidgets/wxWidgets/releases/download/v3.1.0/wxWidgets-3.1.0-headers.7z
# https://github.com/wxWidgets/wxWidgets/releases/download/v3.1.0/wxMSW-3.1.0_vc140_ReleaseDLL.7z
# https://github.com/wxWidgets/wxWidgets/releases/download/v3.1.0/wxMSW-3.1.0_vc140_Dev.7z
# https://github.com/wxWidgets/wxWidgets/releases/download/v3.1.0/wxMSW-3.1.0_vc140_x64_ReleaseDLL.7z
# https://github.com/wxWidgets/wxWidgets/releases/download/v3.1.0/wxMSW-3.1.0_vc140_x64_Dev.7z
# https://github.com/libharu/libharu/archive/RELEASE_2_3_0.zip

D=$PWD

set -e


if ! [ -d "$OSGEO4W_REP" ]; then
	echo Repository not found
	exit
fi

#
# run batch file and source environment changes
#
fetchenv() {
	local IFS
	IFS=
	batch=$1	
	shift
	cmd /c set >$TEMP/srcenv
	cmd /c call `cygpath -w $batch` "$@" \>nul 2\>nul \& set >$TEMP/dstenv
	diff -u $TEMP/srcenv $TEMP/dstenv | sed -f $D/envdiff.sed >$TEMP/diffenv
	. $TEMP/diffenv
	PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
	rm -f $TEMP/srcenv $TEMP/dstenv $TEMP/diffenv
}

export P=saga-ltr
export V=2.3.2
export B=1

cd libharu-RELEASE_2_3_0

if ! [ -f lib-x86/libhpdf.lib ]; then
	(
		fetchenv /cygdrive/c/Program\ Files*/Microsoft\ Visual\ Studio\ 14.0/VC/vcvarsall.bat x86
		nmake -f ../Makefile.haru clean
		nmake -f ../Makefile.haru OSGEO4W_ROOT=C:\\OSGeo4W ARCH=x86 ZLIB=zlib PNGLIB=libpng13.lib
	)
fi
if ! [ -f lib-amd64/libhpdf.lib ]; then
	(
		fetchenv /cygdrive/c/Program\ Files*/Microsoft\ Visual\ Studio\ 14.0/VC/vcvarsall.bat amd64
		nmake -f ../Makefile.haru clean
		nmake -f ../Makefile.haru OSGEO4W_ROOT=C:\\OSGeo4W64 ARCH=amd64 ZLIB=zdll.lib PNGLIB=libpng16.lib
	)
fi

cd ../..

git reset --hard

cd saga-gis

find . -name "*.vcxproj" |
	PWD=$(cygpath -m "$D") \
	O4W_32=$(cygpath -m "c:/osgeo4w") \
	O4W_64=$(cygpath -m "c:/osgeo4w64") \
	xargs perl ../osgeo4w/replace.pl


cd src
fetchenv /cygdrive/c/Program\ Files*/Microsoft\ Visual\ Studio\ 14.0/VC/vcvarsall.bat $VCARCH

sed -i "/{D32A5075-9393-4541-9631-4DE087FAABAC}.*Build\.0.*/d" saga.vc10.sln  # docs_pdf
sed -i "/{AC303E9F-28C5-4F95-8E25-A5D59E8DB01D}.*Build\.0.*/d" saga.vc10.sln  # imagery_opencv
sed -i "/{596A318C-D642-4397-BC7E-6B68BEAA95FC}.*Build\.0.*/d" saga.vc10.sln  # imagery_vigra
sed -i "/{315A9D51-F880-4E45-A890-60FCC4AC71DA}.*Build\.0.*/d" saga.vc10.sln  # io_shapes_las

"/c/Program Files (x86)/Microsoft Visual Studio 14.0/Common7/IDE/devenv" saga.vc10.sln /upgrade
"/c/Program Files (x86)/Microsoft Visual Studio 14.0/Common7/IDE/devenv" saga.vc10.sln /Build "Release|Win32" /Out ..\\..\\osgeo4w\\build-Win32.log
"/c/Program Files (x86)/Microsoft Visual Studio 14.0/Common7/IDE/devenv" saga.vc10.sln /Build "Release|x64" /Out ..\\..\\osgeo4w\\build-x64.log

cd ../../osgeo4w

for a in x86 x86_64; do
	mkdir -p $a/bin $a/etc/postinstall $a/etc/preremove $a/apps/$P

	cat <<EOF >$a/bin/${P}_gui.bat
call "%~dp0\\o4w_env.bat"
"%OSGEO4W_ROOT%\\apps\\$P\\saga_gui.exe"
EOF

	cat <<EOF >$a/etc/postinstall/$P.bat
if "%OSGEO4W_DESKTOP%"=="" set OSGEO4W_DESKTOP=%ALLUSERSPROFILE%\\Desktop

if not %OSGEO4W_DESKTOP_LINKS%==0 mkdir "%OSGEO4W_DESKTOP%"
if not %OSGEO4W_DESKTOP_LINKS%==0 nircmd shortcut "%OSGEO4W_ROOT%\\bin\\nircmd.exe" "%OSGEO4W_DESKTOP%" "SAGA GIS ($V)" "exec hide "%OSGEO4W_ROOT%\\bin\\${P}_gui.bat""" "%OSGEO4W_ROOT%\\apps\\$P\\saga_gui.exe"

if not %OSGEO4W_MENU_LINKS%==0 mkdir "%OSGEO4W_STARTMENU%"
if not %OSGEO4W_MENU_LINKS%==0 nircmd shortcut "%OSGEO4W_ROOT%\\bin\\nircmd.exe" "%OSGEO4W_STARTMENU%" "SAGA GIS ($V)" "exec hide "%OSGEO4W_ROOT%\\bin\\${P}_gui.bat""" "%OSGEO4W_ROOT%\\apps\\$P\\saga_gui.exe"
EOF

	cat <<EOF >$a/etc/preremove/$P.bat
del "%OSGEO4W_STARTMENU%\\SAGA GIS ($V).lnk"
del "%ALLUSERSPROFILE%\\Desktop\\SAGA GIS ($V).lnk"
EOF

done

(
	cd ../saga-gis/bin/saga_vc_Win32
	tar -cf - \
		modules/*.dll \
		saga.*.txt \
		saga_api.dll \
		saga_gdi.dll \
		saga_cmd.exe \
		saga_gui.exe \
		saga_prj.*
) | tar -C x86/apps/$P -xf -

(
	cd ../saga-gis/bin/saga_vc_x64
	tar -cf - \
		modules/*.dll \
		saga.*.txt \
		saga_api.dll \
		saga_gdi.dll \
		saga_cmd.exe \
		saga_gui.exe \
		saga_prj.* \
) | tar -C x86_64/apps/$P -xf -

tar -C lib/vc140_dll -cf - \
	wxbase310u_vc140.dll \
	wxbase310u_net_vc140.dll \
	wxbase310u_xml_vc140.dll \
	wxmsw310u_adv_vc140.dll \
	wxmsw310u_aui_vc140.dll \
	wxmsw310u_core_vc140.dll \
	wxmsw310u_html_vc140.dll \
	wxmsw310u_propgrid_vc140.dll \
	| tar -C x86/apps/$P -xf -

tar -C lib/vc140_x64_dll -cf - \
	wxbase310u_vc140_x64.dll \
	wxbase310u_net_vc140_x64.dll \
	wxbase310u_xml_vc140_x64.dll \
	wxmsw310u_adv_vc140_x64.dll \
	wxmsw310u_aui_vc140_x64.dll \
	wxmsw310u_core_vc140_x64.dll \
	wxmsw310u_html_vc140_x64.dll \
	wxmsw310u_propgrid_vc140_x64.dll \
	| tar -C x86_64/apps/$P -xf -

for a in x86 x86_64; do
	mkdir -p $OSGEO4W_REP/$a/release/saga/$P

	tar -C $a -cjf $OSGEO4W_REP/$a/release/saga/$P/$P-$V-$B.tar.bz2 apps bin etc
	tar -C .. -cjf $OSGEO4W_REP/$a/release/saga/$P/$P-$V-$B-src.tar.bz2 \
		osgeo4w/package.sh \
		osgeo4w/envdiff.sed \
		osgeo4w/replace.pl \
		osgeo4w/Makefile.haru

	cat <<EOF >$OSGEO4W_REP/$a/release/saga/$P/setup.hint
sdesc: "SAGA (System for Automated Geographical Analyses; long-term release)"
ldesc: "SAGA (System for Automated Geographical Analyses; long-term release)"
requires: gdal msvcrt2015
maintainer: JuergenFischer
category: Desktop
EOF
done
